RgbColor

Struct RgbColor 

pub struct RgbColor(pub u8, pub u8, pub u8);
A 24-bit color composed of red, green, and blue components

An RgbColor value can be parsed from a string consisting of '#' followed by six hexadecimal digits or from a string of the form "rgb({red},{blue},{green})" where the individual components are decimal integers from 0 through 255.

RgbColor values are displayed as strings consisting of '#' followed by six lowercase hexadecimal digits.

Examples

use parse_style::RgbColor;

assert_eq!("#e99695".parse::<RgbColor>().unwrap(), RgbColor(233, 150, 149));
assert_eq!("rgb(233,150,149)".parse::<RgbColor>().unwrap(), RgbColor(233, 150, 149));

assert_eq!(RgbColor(233, 150, 149).to_string(), "#e99695");

Tuple Fields

0: u8

Red

1: u8

Green

2: u8

Blue

Implementations

Source

impl RgbColor

pub fn red(self) -> u8

Return the red component

pub fn green(self) -> u8

Return the green component

pub fn blue(self) -> u8

Return the blue component

pub fn as_foreground(self) -> Style

Return a new Style that uses this color as the foreground color

pub fn as_background(self) -> Style

Return a new Style that uses this color as the background color

pub fn on<C: Into<Color>>(self, bg: C) -> Style

Return a new Style that uses this color as the foreground color and bg as the background color